Supported ISPs
==============

All ISP implementations inherit from the base Tekuila class.

TekSavvy
--------

`TekSavvy`_

.. autoclass:: tekuila.isp.teksavvy.Teksavvy
   :members:
   :show-inheritance:

Start.ca
--------

`Start.ca`_

.. autoclass:: tekuila.isp.startca.StartCA
   :members:
   :show-inheritance:

.. _TekSavvy: https://teksavvy.com/
.. _Start.ca: https://www.start.ca/
